@@ -5,11 +5,11 @@ use strict;
 use warnings;
 
 use constant {
-	uECC_secp160r1 => 0,
-	uECC_secp192r1 => 1,
-	uECC_secp224r1 => 2,
-	uECC_secp256r1 => 3,
-	uECC_secp256k1 => 4,
+	secp160r1 => 0,
+	secp192r1 => 1,
+	secp224r1 => 2,
+	secp256r1 => 3,
+	secp256k1 => 4,
 };
 
 require Exporter;
@@ -24,7 +24,7 @@ our @ISA = qw(Exporter);
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
 our %EXPORT_TAGS = ( 'all' => [ qw(
-  uECC_secp160r1 uECC_secp192r1 uECC_secp224r1 uECC_secp256r1 uECC_secp256k1
+  secp160r1 secp192r1 secp224r1 secp256r1 secp256k1
   make_key valid_public_key shared_secret curve_public_key_size curve_private_key_size
   compute_public_key verify sign
 ) ] );
@@ -35,7 +35,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 require XSLoader;
 XSLoader::load('MicroECC', $VERSION);
@@ -50,15 +50,15 @@ __END__
 
 =head1 NAME
 
-MicroECC - Perl extension for the micro-ecc library
+MicroECC - Perl wrapper for the micro-ecc ECDH and ECDSA library
 
 =head1 SYNOPSIS
 
   use MicroECC;
   use Digest::SHA qw/sha1 sha256/;
 
-  #curves: uECC_secp160r1 uECC_secp192r1 uECC_secp224r1 uECC_secp256r1 uECC_secp256k1
-  my $curve = MicroECC::uECC_secp160r1();
+  #curves: secp160r1 secp192r1 secp224r1 secp256r1 secp256k1
+  my $curve = MicroECC::secp160r1();
   printf "Public key size: %d, private key size: %d.\n", 
 	  MicroECC::curve_public_key_size($curve), MicroECC::curve_private_key_size($curve);
 
